searchData={"items":[{"type":"module","title":"BentoSdk","doc":"BentoSdk is an Elixir client for the Bento API.","ref":"BentoSdk.html"},{"type":"module","title":"Configuration - BentoSdk","doc":"Add the following to your config.exs (or environment specific config file) to use environment variables:\n\n    config :bento_sdk,\n      site_uuid: System.get_env(\"BENTO_SITE_UUID\", \"your_site_uuid\"),\n      username: System.get_env(\"BENTO_USERNAME\", \"your_username\"),\n      password: System.get_env(\"BENTO_PASSWORD\", \"your_password\")\n\nAlternatively, you can set the configuration at runtime:\n\n    BentoSdk.configure(\n      site_uuid: \"your-site-uuid\",\n      username: \"your-username\",\n      password: \"your-password\"\n    )","ref":"BentoSdk.html#module-configuration"},{"type":"module","title":"Usage - BentoSdk","doc":"The SDK is organized into modules by functionality:\n\n```elixir\n# Subscriber operations\n{:ok, subscriber} = BentoSdk.Subscribers.find(\"user@example.com\")\n{:ok, subscriber} = BentoSdk.Subscribers.create(\"user@example.com\")\n{:ok, subscriber} = BentoSdk.Subscribers.find_or_create(\"user@example.com\")\n{:ok, subscriber} = BentoSdk.Subscribers.update(\"user@example.com\", %{first_name: \"John\"})\n\n# Tag operations\n{:ok, tags} = BentoSdk.Tags.get()\n{:ok, tag} = BentoSdk.Tags.create(\"new_tag\")\n{:ok, result} = BentoSdk.Subscribers.add_tag(\"user@example.com\", \"vip\")\n{:ok, result} = BentoSdk.Subscribers.remove_tag(\"user@example.com\", \"vip\")\n\n# Field operations\n{:ok, fields} = BentoSdk.Fields.get()\n{:ok, field} = BentoSdk.Fields.create(\"company\")\n{:ok, result} = BentoSdk.Subscribers.add_field(\"user@example.com\", \"company\", \"Acme Inc.\")\n{:ok, result} = BentoSdk.Subscribers.remove_field(\"user@example.com\", \"company\")\n\n# Event operations\n{:ok, result} = BentoSdk.Events.track(\"user@example.com\", \"page_viewed\", %{page: \"/products\"})\n{:ok, result} = BentoSdk.Events.import_events([%{email: \"user@example.com\", type: \"page_viewed\"}])\n\n# Email operations\n{:ok, result} = BentoSdk.Emails.send(\"user@example.com\", \"noreply@example.com\", \"Welcome\", \" Welcome! \")\n\n# Stats operations\n{:ok, stats} = BentoSdk.Stats.get_site()\n{:ok, stats} = BentoSdk.Stats.get_segment(\"segment_id\")\n{:ok, stats} = BentoSdk.Stats.get_report(\"report_id\")\n\n# Utility operations\n{:ok, result} = BentoSdk.Utility.moderate_content(\"Some content\")\n{:ok, result} = BentoSdk.Utility.guess_gender(\"Alex\")\n{:ok, result} = BentoSdk.Utility.geolocate(\"8.8.8.8\")\n{:ok, result} = BentoSdk.Utility.validate_email(\"user@example.com\")\n{:ok, reasons} = BentoSdk.Utility.jesses_ruleset(\"user@example.com\", block_free_providers: true)\n{:ok, result} = BentoSdk.Utility.check_blacklist(%{domain: \"example.com\"})\n\n# Broadcasts operations\n{:ok, broadcasts} = BentoSdk.Broadcasts.get()\n{:ok, broadcast} = BentoSdk.Broadcasts.create([%{name: \"Campaign\", subject: \"Hello\", content: \" Hi \"}])\n```","ref":"BentoSdk.html#module-usage"},{"type":"function","title":"BentoSdk.configure/1","doc":"Configure the BentoSdk at runtime.","ref":"BentoSdk.html#configure/1"},{"type":"function","title":"Options - BentoSdk.configure/1","doc":"* `:site_uuid` - Your Bento site UUID\n  * `:username` - Your Bento API username\n  * `:password` - Your Bento API password\n  * `:client` - A module that implements `BentoSdk.ClientBehaviour`","ref":"BentoSdk.html#configure/1-options"},{"type":"function","title":"Examples - BentoSdk.configure/1","doc":"BentoSdk.configure(\n      site_uuid: \"your-site-uuid\",\n      username: \"your-username\",\n      password: \"your-password\"\n    )\n\n    # Or with a custom client\n    BentoSdk.configure(\n      site_uuid: \"your-site-uuid\",\n      username: \"your-username\",\n      password: \"your-password\",\n      client: MyCustomClient\n    )","ref":"BentoSdk.html#configure/1-examples"},{"type":"module","title":"BentoSdk.Broadcasts","doc":"Functions for managing broadcasts in Bento.\n\nThis module provides functions to interact with the Bento Broadcasts API,\nallowing you to get and create broadcasts.","ref":"BentoSdk.Broadcasts.html"},{"type":"function","title":"BentoSdk.Broadcasts.create/1","doc":"Create new broadcasts.\n\nCreates one or more new broadcasts to be sent to your subscribers.","ref":"BentoSdk.Broadcasts.html#create/1"},{"type":"function","title":"Parameters - BentoSdk.Broadcasts.create/1","doc":"- `broadcasts` - A list of broadcast maps with the following keys:\n  - `name` - Name of the broadcast (e.g., campaign name)\n  - `subject` - Subject line of the broadcast email\n  - `content` - Broadcast body content (supports liquid tags)\n  - `type` - Email type (\"plain\" for Bento's CSS or \"raw\" to use your own)\n  - `from` - Map with `email` and `name` keys for the sender\n  - `inclusive_tags` - Comma-separated list of tags to send to (optional)\n  - `exclusive_tags` - Comma-separated list of tags to exclude (optional)\n  - `segment_id` - Segment ID for the campaign (optional)\n  - `batch_size_per_hour` - Number of emails to send per hour (optional)\n  - `send_at` - Date and time to send the broadcast (optional, format: \"2024-04-23T18:30:00Z\")\n  - `approved` - Whether the broadcast is approved to be sent (optional, boolean)","ref":"BentoSdk.Broadcasts.html#create/1-parameters"},{"type":"function","title":"Examples - BentoSdk.Broadcasts.create/1","doc":"broadcasts = [\n      %{\n        name: \"Campaign #1 — Plain Text Example\",\n        subject: \"Hello Plain World\",\n        content: \" Hi {{ visitor.first_name }} \",\n        type: \"plain\",\n        from: %{\n          email: \"sender@example.com\",\n          name: \"John Doe\"\n        },\n        inclusive_tags: \"lead,mql\",\n        exclusive_tags: \"customers\",\n        segment_id: \"segment_123456789\",\n        batch_size_per_hour: 1500\n      }\n    ]\n\n    BentoSdk.Broadcasts.create(broadcasts)\n    {:ok, %{\"results\" => 1}}","ref":"BentoSdk.Broadcasts.html#create/1-examples"},{"type":"function","title":"BentoSdk.Broadcasts.get/0","doc":"Get a list of broadcasts.\n\nReturns a list of all broadcasts in your Bento account.","ref":"BentoSdk.Broadcasts.html#get/0"},{"type":"function","title":"Examples - BentoSdk.Broadcasts.get/0","doc":"BentoSdk.Broadcasts.get()\n    {:ok, [\n      %{\n        \"id\" => \"broadcast_123\",\n        \"type\" => \"broadcast\",\n        \"attributes\" => %{\n          \"name\" => \"Campaign #1\",\n          \"share_url\" => \"https://example.com/share/broadcast_123\",\n          \"template\" => %{\n            \"subject\" => \"Hello World\",\n            \"to\" => \"Subscribers\",\n            \"html\" => \" Hi {{ visitor.first_name }} \"\n          },\n          \"created_at\" => \"2024-08-06T05:44:04.433Z\",\n          \"sent_final_batch_at\" => \"2024-08-06T05:44:04.433Z\",\n          \"send_at\" => \"2024-08-06T05:44:04.433Z\",\n          \"stats\" => %{\n            \"open_rate\" => 0.25\n          }\n        }\n      }\n    ]}","ref":"BentoSdk.Broadcasts.html#get/0-examples"},{"type":"module","title":"BentoSdk.Client","doc":"HTTP client for the Bento API.","ref":"BentoSdk.Client.html"},{"type":"function","title":"BentoSdk.Client.add_field/3","doc":"Add a field to a subscriber.","ref":"BentoSdk.Client.html#add_field/3"},{"type":"function","title":"BentoSdk.Client.add_tag/2","doc":"Add a tag to a subscriber.","ref":"BentoSdk.Client.html#add_tag/2"},{"type":"function","title":"BentoSdk.Client.add_tag_via_event/2","doc":"Add a tag to a subscriber via an event.","ref":"BentoSdk.Client.html#add_tag_via_event/2"},{"type":"function","title":"BentoSdk.Client.change_email/2","doc":"Change a subscriber's email.","ref":"BentoSdk.Client.html#change_email/2"},{"type":"function","title":"BentoSdk.Client.check_blacklist/1","doc":"Check if a domain or IP address is on any blacklists.\n\nReturns a map with blacklist check results.","ref":"BentoSdk.Client.html#check_blacklist/1"},{"type":"function","title":"BentoSdk.Client.create_broadcasts/1","doc":"Create new broadcasts.","ref":"BentoSdk.Client.html#create_broadcasts/1"},{"type":"function","title":"BentoSdk.Client.create_field/1","doc":"Create a new field in your account.\n\nReturns the details of the created field.","ref":"BentoSdk.Client.html#create_field/1"},{"type":"function","title":"BentoSdk.Client.create_subscriber/1","doc":"Create a subscriber in Bento.","ref":"BentoSdk.Client.html#create_subscriber/1"},{"type":"function","title":"BentoSdk.Client.create_tag/1","doc":"Create a new tag in your account.","ref":"BentoSdk.Client.html#create_tag/1"},{"type":"function","title":"BentoSdk.Client.email_risky?/1","doc":"Check if an email is risky.","ref":"BentoSdk.Client.html#email_risky?/1"},{"type":"function","title":"BentoSdk.Client.email_valid?/1","doc":"Check if an email is valid.","ref":"BentoSdk.Client.html#email_valid?/1"},{"type":"function","title":"BentoSdk.Client.find_or_create_subscriber/1","doc":"Find or create a subscriber in Bento.","ref":"BentoSdk.Client.html#find_or_create_subscriber/1"},{"type":"function","title":"BentoSdk.Client.find_subscriber/1","doc":"Find a subscriber in Bento.","ref":"BentoSdk.Client.html#find_subscriber/1"},{"type":"function","title":"BentoSdk.Client.geolocate/1","doc":"Geolocate an IP address.\n\nReturns a map with geolocation information.","ref":"BentoSdk.Client.html#geolocate/1"},{"type":"function","title":"BentoSdk.Client.get_broadcast_stats/1","doc":"Get broadcast statistics.\n\nReturns statistics for a specific broadcast.","ref":"BentoSdk.Client.html#get_broadcast_stats/1"},{"type":"function","title":"BentoSdk.Client.get_broadcasts/0","doc":"Get a list of broadcasts.","ref":"BentoSdk.Client.html#get_broadcasts/0"},{"type":"function","title":"BentoSdk.Client.get_email_stats/2","doc":"Get email statistics for a time period.\n\nReturns a map with email statistics.","ref":"BentoSdk.Client.html#get_email_stats/2"},{"type":"function","title":"BentoSdk.Client.get_fields/0","doc":"Get all fields in your account.\n\nReturns a list of fields.","ref":"BentoSdk.Client.html#get_fields/0"},{"type":"function","title":"BentoSdk.Client.get_report_stats/1","doc":"Get report statistics.\n\nReturns data for a specific report.","ref":"BentoSdk.Client.html#get_report_stats/1"},{"type":"function","title":"BentoSdk.Client.get_segment_stats/1","doc":"Get segment statistics.\n\nReturns statistics for a specific segment, including user count,\nsubscriber count, and unsubscriber count.","ref":"BentoSdk.Client.html#get_segment_stats/1"},{"type":"function","title":"BentoSdk.Client.get_site_stats/0","doc":"Get site statistics.\n\nReturns basic statistics about your Bento site, including user count,\nsubscriber count, and unsubscriber count.","ref":"BentoSdk.Client.html#get_site_stats/0"},{"type":"function","title":"BentoSdk.Client.get_subscriber_growth/2","doc":"Get subscriber growth statistics.\n\nReturns subscriber growth statistics for a specific time period.","ref":"BentoSdk.Client.html#get_subscriber_growth/2"},{"type":"function","title":"BentoSdk.Client.get_tag_stats/3","doc":"Get tag statistics.\n\nReturns statistics for a specific tag over a time period.","ref":"BentoSdk.Client.html#get_tag_stats/3"},{"type":"function","title":"BentoSdk.Client.get_tags/0","doc":"Get all tags in your account.","ref":"BentoSdk.Client.html#get_tags/0"},{"type":"function","title":"BentoSdk.Client.guess_gender/1","doc":"Guess the gender of a name.\n\nReturns a map with gender probability information.","ref":"BentoSdk.Client.html#guess_gender/1"},{"type":"function","title":"BentoSdk.Client.import_events/1","doc":"Import events in bulk.","ref":"BentoSdk.Client.html#import_events/1"},{"type":"function","title":"BentoSdk.Client.import_subscribers/1","doc":"Import or update subscribers in bulk.","ref":"BentoSdk.Client.html#import_subscribers/1"},{"type":"function","title":"BentoSdk.Client.jesses_ruleset/2","doc":"Check against the special \"Jesse's Ruleset\".","ref":"BentoSdk.Client.html#jesses_ruleset/2"},{"type":"function","title":"BentoSdk.Client.moderate_content/1","doc":"Moderate content for profanity and other inappropriate content.\n\nReturns a map with moderation results.","ref":"BentoSdk.Client.html#moderate_content/1"},{"type":"function","title":"BentoSdk.Client.remove_field/2","doc":"Remove a field from a subscriber.","ref":"BentoSdk.Client.html#remove_field/2"},{"type":"function","title":"BentoSdk.Client.remove_tag/2","doc":"Remove a tag from a subscriber.","ref":"BentoSdk.Client.html#remove_tag/2"},{"type":"function","title":"BentoSdk.Client.run_command/3","doc":"Run a command to change a subscriber's data.","ref":"BentoSdk.Client.html#run_command/3"},{"type":"function","title":"BentoSdk.Client.send_email/6","doc":"Send an email through Bento.","ref":"BentoSdk.Client.html#send_email/6"},{"type":"function","title":"BentoSdk.Client.subscribe/1","doc":"Subscribe a user.","ref":"BentoSdk.Client.html#subscribe/1"},{"type":"function","title":"BentoSdk.Client.track_event/4","doc":"Track an event in Bento.","ref":"BentoSdk.Client.html#track_event/4"},{"type":"function","title":"BentoSdk.Client.unsubscribe/1","doc":"Unsubscribe a user.","ref":"BentoSdk.Client.html#unsubscribe/1"},{"type":"function","title":"BentoSdk.Client.validate_email/2","doc":"Validate an email address using Bento's validation service.\n\nReturns a map with validation results.","ref":"BentoSdk.Client.html#validate_email/2"},{"type":"behaviour","title":"BentoSdk.ClientBehaviour","doc":"Behaviour for the Bento API client.\nThis allows us to mock the client in tests.","ref":"BentoSdk.ClientBehaviour.html"},{"type":"callback","title":"BentoSdk.ClientBehaviour.add_field/3","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:add_field/3"},{"type":"callback","title":"BentoSdk.ClientBehaviour.add_tag/2","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:add_tag/2"},{"type":"callback","title":"BentoSdk.ClientBehaviour.add_tag_via_event/2","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:add_tag_via_event/2"},{"type":"callback","title":"BentoSdk.ClientBehaviour.change_email/2","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:change_email/2"},{"type":"callback","title":"BentoSdk.ClientBehaviour.check_blacklist/1","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:check_blacklist/1"},{"type":"callback","title":"BentoSdk.ClientBehaviour.create_broadcasts/1","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:create_broadcasts/1"},{"type":"callback","title":"BentoSdk.ClientBehaviour.create_field/1","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:create_field/1"},{"type":"callback","title":"BentoSdk.ClientBehaviour.create_subscriber/1","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:create_subscriber/1"},{"type":"callback","title":"BentoSdk.ClientBehaviour.create_tag/1","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:create_tag/1"},{"type":"callback","title":"BentoSdk.ClientBehaviour.find_or_create_subscriber/1","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:find_or_create_subscriber/1"},{"type":"callback","title":"BentoSdk.ClientBehaviour.find_subscriber/1","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:find_subscriber/1"},{"type":"callback","title":"BentoSdk.ClientBehaviour.geolocate/1","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:geolocate/1"},{"type":"callback","title":"BentoSdk.ClientBehaviour.get_broadcasts/0","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:get_broadcasts/0"},{"type":"callback","title":"BentoSdk.ClientBehaviour.get_fields/0","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:get_fields/0"},{"type":"callback","title":"BentoSdk.ClientBehaviour.get_report_stats/1","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:get_report_stats/1"},{"type":"callback","title":"BentoSdk.ClientBehaviour.get_segment_stats/1","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:get_segment_stats/1"},{"type":"callback","title":"BentoSdk.ClientBehaviour.get_site_stats/0","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:get_site_stats/0"},{"type":"callback","title":"BentoSdk.ClientBehaviour.get_subscriber_growth/2","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:get_subscriber_growth/2"},{"type":"callback","title":"BentoSdk.ClientBehaviour.get_tags/0","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:get_tags/0"},{"type":"callback","title":"BentoSdk.ClientBehaviour.guess_gender/1","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:guess_gender/1"},{"type":"callback","title":"BentoSdk.ClientBehaviour.import_events/1","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:import_events/1"},{"type":"callback","title":"BentoSdk.ClientBehaviour.import_subscribers/1","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:import_subscribers/1"},{"type":"callback","title":"BentoSdk.ClientBehaviour.jesses_ruleset/2","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:jesses_ruleset/2"},{"type":"callback","title":"BentoSdk.ClientBehaviour.moderate_content/1","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:moderate_content/1"},{"type":"callback","title":"BentoSdk.ClientBehaviour.remove_field/2","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:remove_field/2"},{"type":"callback","title":"BentoSdk.ClientBehaviour.remove_tag/2","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:remove_tag/2"},{"type":"callback","title":"BentoSdk.ClientBehaviour.run_command/3","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:run_command/3"},{"type":"callback","title":"BentoSdk.ClientBehaviour.send_bulk_emails/1","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:send_bulk_emails/1"},{"type":"callback","title":"BentoSdk.ClientBehaviour.send_email/5","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:send_email/5"},{"type":"callback","title":"BentoSdk.ClientBehaviour.send_transactional_email/5","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:send_transactional_email/5"},{"type":"callback","title":"BentoSdk.ClientBehaviour.subscribe/1","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:subscribe/1"},{"type":"callback","title":"BentoSdk.ClientBehaviour.track_event/4","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:track_event/4"},{"type":"callback","title":"BentoSdk.ClientBehaviour.unsubscribe/1","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:unsubscribe/1"},{"type":"callback","title":"BentoSdk.ClientBehaviour.validate_email/2","doc":"","ref":"BentoSdk.ClientBehaviour.html#c:validate_email/2"},{"type":"module","title":"BentoSdk.Emails","doc":"Functions for sending emails through Bento.","ref":"BentoSdk.Emails.html"},{"type":"function","title":"BentoSdk.Emails.send/5","doc":"Send a single email to a subscriber.\nThis respects subscription status - unsubscribed users won't receive the email.","ref":"BentoSdk.Emails.html#send/5"},{"type":"function","title":"Parameters - BentoSdk.Emails.send/5","doc":"* `to` - The email address of the recipient\n  * `from` - The email address of the sender (must be an author in your account)\n  * `subject` - The subject of the email\n  * `html_body` - The HTML body of the email\n  * `personalizations` - Key-value pairs of custom data to be injected into the email","ref":"BentoSdk.Emails.html#send/5-parameters"},{"type":"function","title":"Examples - BentoSdk.Emails.send/5","doc":"BentoSdk.Emails.send(\n      \"user@example.com\",\n      \"noreply@yourdomain.com\",\n      \"Welcome to our service\",\n      \" Welcome!  Thanks for signing up. \",\n      %{\n        \"first_name\" => \"John\"\n      }\n    )\n    {:ok, %{\n      \"results\" => 1\n    }}","ref":"BentoSdk.Emails.html#send/5-examples"},{"type":"function","title":"BentoSdk.Emails.send_bulk/1","doc":"Send multiple emails in a single batch.","ref":"BentoSdk.Emails.html#send_bulk/1"},{"type":"function","title":"Parameters - BentoSdk.Emails.send_bulk/1","doc":"* `emails` - A list of email maps, each with the following keys:\n    * `to` - The email address of the recipient\n    * `from` - The email address of the sender\n    * `subject` - The subject of the email\n    * `html_body` - The HTML body of the email\n    * `personalizations` - Key-value pairs of custom data (optional)\n    * `transactional` - Whether this is a transactional email (optional)","ref":"BentoSdk.Emails.html#send_bulk/1-parameters"},{"type":"function","title":"Examples - BentoSdk.Emails.send_bulk/1","doc":"BentoSdk.Emails.send_bulk([\n      %{\n        to: \"user1@example.com\",\n        from: \"noreply@yourdomain.com\",\n        subject: \"Welcome to our service\",\n        html_body: \" Welcome!  Thanks for signing up. \",\n        personalizations: %{\"first_name\" => \"John\"}\n      },\n      %{\n        to: \"user2@example.com\",\n        from: \"noreply@yourdomain.com\",\n        subject: \"Your order has shipped\",\n        html_body: \" Order Shipped  Your order #123 has shipped. \",\n        personalizations: %{\"first_name\" => \"Jane\", \"order_number\" => \"123\"},\n        transactional: true\n      }\n    ])\n    {:ok, %{\n      \"results\" => 2\n    }}","ref":"BentoSdk.Emails.html#send_bulk/1-examples"},{"type":"function","title":"BentoSdk.Emails.send_transactional/5","doc":"Send a transactional email to a subscriber.\nThis will always send, even if the user is unsubscribed.","ref":"BentoSdk.Emails.html#send_transactional/5"},{"type":"function","title":"Parameters - BentoSdk.Emails.send_transactional/5","doc":"* `to` - The email address of the recipient\n  * `from` - The email address of the sender (must be an author in your account)\n  * `subject` - The subject of the email\n  * `html_body` - The HTML body of the email\n  * `personalizations` - Key-value pairs of custom data to be injected into the email","ref":"BentoSdk.Emails.html#send_transactional/5-parameters"},{"type":"function","title":"Examples - BentoSdk.Emails.send_transactional/5","doc":"BentoSdk.Emails.send_transactional(\n      \"user@example.com\",\n      \"noreply@yourdomain.com\",\n      \"Your order has shipped\",\n      \" Order Shipped  Your order #123 has shipped. \",\n      %{\n        \"first_name\" => \"John\",\n        \"order_number\" => \"123\"\n      }\n    )\n    {:ok, %{\n      \"results\" => 1\n    }}","ref":"BentoSdk.Emails.html#send_transactional/5-examples"},{"type":"function","title":"BentoSdk.Emails.validate_email/1","doc":"Validates that an email address is properly formatted.\nRaises an ArgumentError if the email is invalid.","ref":"BentoSdk.Emails.html#validate_email/1"},{"type":"function","title":"Parameters - BentoSdk.Emails.validate_email/1","doc":"* `email` - The email address to validate","ref":"BentoSdk.Emails.html#validate_email/1-parameters"},{"type":"function","title":"Examples - BentoSdk.Emails.validate_email/1","doc":"BentoSdk.Emails.validate_email(\"user@example.com\")\n    :ok\n\n    BentoSdk.Emails.validate_email(\"invalid-email\")\n    ** (ArgumentError) Invalid email format","ref":"BentoSdk.Emails.html#validate_email/1-examples"},{"type":"module","title":"BentoSdk.Events","doc":"Functions for tracking events in Bento.\n\nThe Events API allows you to track user behavior and trigger automations in Bento.\nEvents will create new users if they don't already exist in your account.","ref":"BentoSdk.Events.html"},{"type":"function","title":"BentoSdk.Events.import_events/1","doc":"Import events in bulk.","ref":"BentoSdk.Events.html#import_events/1"},{"type":"function","title":"Parameters - BentoSdk.Events.import_events/1","doc":"* `events` - A list of event maps, each with the following keys:\n    * `email` - The email address of the subscriber\n    * `type` - The type of event\n    * `fields` - Key-value pairs of data for the event (optional, should not be nested)\n    * `details` - Key-value pairs of data for the event (optional, can be nested)","ref":"BentoSdk.Events.html#import_events/1-parameters"},{"type":"function","title":"Examples - BentoSdk.Events.import_events/1","doc":"BentoSdk.Events.import_events([\n      %{\n        email: \"user1@example.com\",\n        type: \"page_viewed\",\n        fields: %{\n          \"page\" => \"/products\",\n          \"referrer\" => \"https://google.com\"\n        }\n      },\n      %{\n        email: \"user2@example.com\",\n        type: \"$purchase\",\n        fields: %{\n          \"first_name\" => \"Jane\"\n        },\n        details: %{\n          \"value\" => %{\n            \"currency\" => \"USD\",\n            \"amount\" => 4999\n          }\n        }\n      }\n    ])\n    {:ok, %{\n      \"results\" => 2,\n      \"failed\" => 0\n    }}","ref":"BentoSdk.Events.html#import_events/1-examples"},{"type":"function","title":"BentoSdk.Events.track/4","doc":"Track an event for a subscriber.","ref":"BentoSdk.Events.html#track/4"},{"type":"function","title":"Parameters - BentoSdk.Events.track/4","doc":"* `email` - The email address of the subscriber\n  * `type` - The type of event (e.g., \"page_viewed\", \"product_added_to_cart\")\n  * `fields` - Key-value pairs of data for the event (should not be nested)\n  * `details` - Key-value pairs of data for the event (can be nested)","ref":"BentoSdk.Events.html#track/4-parameters"},{"type":"function","title":"Examples - BentoSdk.Events.track/4","doc":"# Basic event\n    BentoSdk.Events.track(\"user@example.com\", \"page_viewed\")\n    {:ok, %{\n      \"results\" => 1,\n      \"failed\" => 0\n    }}\n\n    # Event with fields\n    BentoSdk.Events.track(\n      \"user@example.com\",\n      \"page_viewed\",\n      %{\n        \"page\" => \"/products\",\n        \"referrer\" => \"https://google.com\"\n      }\n    )\n    {:ok, %{\n      \"results\" => 1,\n      \"failed\" => 0\n    }}\n\n    # Complex event with fields and details\n    BentoSdk.Events.track(\n      \"user@example.com\",\n      \"$purchase\",\n      %{\n        \"first_name\" => \"Jesse\"\n      },\n      %{\n        \"unique\" => %{\n          \"key\" => \"order_123\"\n        },\n        \"value\" => %{\n          \"currency\" => \"USD\",\n          \"amount\" => 8000\n        },\n        \"cart\" => %{\n          \"items\" => [\n            %{\n              \"product_sku\" => \"SKU123\",\n              \"product_name\" => \"Test Product\",\n              \"quantity\" => 1\n            }\n          ],\n          \"abandoned_checkout_url\" => \"https://example.com/cart\"\n        }\n      }\n    )\n    {:ok, %{\n      \"results\" => 1,\n      \"failed\" => 0\n    }}","ref":"BentoSdk.Events.html#track/4-examples"},{"type":"function","title":"BentoSdk.Events.validate_details/1","doc":"Validates event details.\nRaises an ArgumentError if the details are invalid.","ref":"BentoSdk.Events.html#validate_details/1"},{"type":"function","title":"Parameters - BentoSdk.Events.validate_details/1","doc":"* `details` - The event details to validate","ref":"BentoSdk.Events.html#validate_details/1-parameters"},{"type":"function","title":"BentoSdk.Events.validate_email/1","doc":"Validates an email address.\nRaises an ArgumentError if the email is invalid.","ref":"BentoSdk.Events.html#validate_email/1"},{"type":"function","title":"Parameters - BentoSdk.Events.validate_email/1","doc":"* `email` - The email address to validate","ref":"BentoSdk.Events.html#validate_email/1-parameters"},{"type":"function","title":"BentoSdk.Events.validate_event/1","doc":"Validates an event.\nRaises an ArgumentError if the event is invalid.","ref":"BentoSdk.Events.html#validate_event/1"},{"type":"function","title":"Parameters - BentoSdk.Events.validate_event/1","doc":"* `event` - The event to validate","ref":"BentoSdk.Events.html#validate_event/1-parameters"},{"type":"function","title":"BentoSdk.Events.validate_fields/1","doc":"Validates event fields.\nRaises an ArgumentError if the fields are invalid.","ref":"BentoSdk.Events.html#validate_fields/1"},{"type":"function","title":"Parameters - BentoSdk.Events.validate_fields/1","doc":"* `fields` - The event fields to validate","ref":"BentoSdk.Events.html#validate_fields/1-parameters"},{"type":"function","title":"BentoSdk.Events.validate_type/1","doc":"Validates an event type.\nRaises an ArgumentError if the type is invalid.","ref":"BentoSdk.Events.html#validate_type/1"},{"type":"function","title":"Parameters - BentoSdk.Events.validate_type/1","doc":"* `type` - The event type to validate","ref":"BentoSdk.Events.html#validate_type/1-parameters"},{"type":"module","title":"BentoSdk.Fields","doc":"Functions for managing fields in Bento.\n\nThe Fields API allows you to:\n- Get all fields in your account\n- Create new fields\n\nFields are simple named key-value pairs, think of them as form fields.","ref":"BentoSdk.Fields.html"},{"type":"function","title":"BentoSdk.Fields.create/1","doc":"Create a new field in your account.","ref":"BentoSdk.Fields.html#create/1"},{"type":"function","title":"Examples - BentoSdk.Fields.create/1","doc":"BentoSdk.Fields.create(\"company\")\n    {:ok, %{\n      \"id\" => \"1234\",\n      \"type\" => \"fields\",\n      \"attributes\" => %{\n        \"key\" => \"company\",\n        \"created_at\" => \"2024-08-06T05:44:04.444Z\",\n        \"discarded_at\" => nil\n      }\n    }}","ref":"BentoSdk.Fields.html#create/1-examples"},{"type":"function","title":"BentoSdk.Fields.get/0","doc":"Get all fields in your account.","ref":"BentoSdk.Fields.html#get/0"},{"type":"function","title":"Examples - BentoSdk.Fields.get/0","doc":"BentoSdk.Fields.get()\n    {:ok, [\n      %{\n        \"id\" => \"1234\",\n        \"type\" => \"fields\",\n        \"attributes\" => %{\n          \"key\" => \"company\",\n          \"created_at\" => \"2024-08-06T05:44:04.444Z\",\n          \"discarded_at\" => nil\n        }\n      }\n    ]}","ref":"BentoSdk.Fields.html#get/0-examples"},{"type":"module","title":"BentoSdk.Stats","doc":"Functions for retrieving statistics from Bento.\n\nThe Stats API allows you to:\n- Get site statistics\n- Get segment statistics\n- Get report statistics\n\nThese statistics provide insights into your Bento account's performance.","ref":"BentoSdk.Stats.html"},{"type":"function","title":"BentoSdk.Stats.get_report/1","doc":"Get report statistics.\n\nReturns data for a specific report.","ref":"BentoSdk.Stats.html#get_report/1"},{"type":"function","title":"Parameters - BentoSdk.Stats.get_report/1","doc":"* `report_id` - The ID of the report to get data for","ref":"BentoSdk.Stats.html#get_report/1-parameters"},{"type":"function","title":"Examples - BentoSdk.Stats.get_report/1","doc":"iex> BentoSdk.Stats.get_report(\"456\")\n    {:ok, %{\n      \"report_data\" => %{\n        \"data\" => %{},\n        \"chart_style\" => \"count\",\n        \"report_type\" => \"Reporting::Reports::VisitorCountReport\",\n        \"report_name\" => \"New Subscribers\"\n      }\n    }}","ref":"BentoSdk.Stats.html#get_report/1-examples"},{"type":"function","title":"BentoSdk.Stats.get_segment/1","doc":"Get segment statistics.\n\nReturns statistics for a specific segment.","ref":"BentoSdk.Stats.html#get_segment/1"},{"type":"function","title":"Parameters - BentoSdk.Stats.get_segment/1","doc":"* `segment_id` - The ID of the segment to get statistics for","ref":"BentoSdk.Stats.html#get_segment/1-parameters"},{"type":"function","title":"Examples - BentoSdk.Stats.get_segment/1","doc":"iex> BentoSdk.Stats.get_segment(\"123\")\n    {:ok, %{\n      \"user_count\" => 500,\n      \"subscriber_count\" => 400,\n      \"unsubscriber_count\" => 100\n    }}","ref":"BentoSdk.Stats.html#get_segment/1-examples"},{"type":"function","title":"BentoSdk.Stats.get_site/0","doc":"Get site statistics.\n\nReturns basic statistics about your Bento site.","ref":"BentoSdk.Stats.html#get_site/0"},{"type":"function","title":"Examples - BentoSdk.Stats.get_site/0","doc":"iex> BentoSdk.Stats.get_site()\n    {:ok, %{\n      \"user_count\" => 1000,\n      \"subscriber_count\" => 800,\n      \"unsubscriber_count\" => 200\n    }}","ref":"BentoSdk.Stats.html#get_site/0-examples"},{"type":"module","title":"BentoSdk.Subscribers","doc":"Functions for managing subscribers in Bento.","ref":"BentoSdk.Subscribers.html"},{"type":"function","title":"BentoSdk.Subscribers.add_field/3","doc":"Add a field to a subscriber.","ref":"BentoSdk.Subscribers.html#add_field/3"},{"type":"function","title":"Examples - BentoSdk.Subscribers.add_field/3","doc":"BentoSdk.Subscribers.add_field(\"user@example.com\", \"company\", \"Acme Inc.\")\n    {:ok, %{\n      \"success\" => true\n    }}","ref":"BentoSdk.Subscribers.html#add_field/3-examples"},{"type":"function","title":"BentoSdk.Subscribers.add_tag/2","doc":"Add a tag to a subscriber.","ref":"BentoSdk.Subscribers.html#add_tag/2"},{"type":"function","title":"Examples - BentoSdk.Subscribers.add_tag/2","doc":"BentoSdk.Subscribers.add_tag(\"user@example.com\", \"vip\")\n    {:ok, %{\n      \"success\" => true\n    }}","ref":"BentoSdk.Subscribers.html#add_tag/2-examples"},{"type":"function","title":"BentoSdk.Subscribers.add_tag_via_event/2","doc":"Add a tag to a subscriber via an event.","ref":"BentoSdk.Subscribers.html#add_tag_via_event/2"},{"type":"function","title":"Examples - BentoSdk.Subscribers.add_tag_via_event/2","doc":"BentoSdk.Subscribers.add_tag_via_event(\"user@example.com\", \"vip\")\n    {:ok, %{\n      \"success\" => true\n    }}","ref":"BentoSdk.Subscribers.html#add_tag_via_event/2-examples"},{"type":"function","title":"BentoSdk.Subscribers.add_tags/2","doc":"Add multiple tags to a subscriber.","ref":"BentoSdk.Subscribers.html#add_tags/2"},{"type":"function","title":"Examples - BentoSdk.Subscribers.add_tags/2","doc":"BentoSdk.Subscribers.add_tags(\"user@example.com\", [\"vip\", \"new\"])\n    {:ok, %{\n      \"success\" => true\n    }}","ref":"BentoSdk.Subscribers.html#add_tags/2-examples"},{"type":"function","title":"BentoSdk.Subscribers.change_email/2","doc":"Change a subscriber's email.","ref":"BentoSdk.Subscribers.html#change_email/2"},{"type":"function","title":"Examples - BentoSdk.Subscribers.change_email/2","doc":"BentoSdk.Subscribers.change_email(\"old@example.com\", \"new@example.com\")\n    {:ok, %{\n      \"success\" => true\n    }}","ref":"BentoSdk.Subscribers.html#change_email/2-examples"},{"type":"function","title":"BentoSdk.Subscribers.create/1","doc":"Create a subscriber with the given email.","ref":"BentoSdk.Subscribers.html#create/1"},{"type":"function","title":"Examples - BentoSdk.Subscribers.create/1","doc":"BentoSdk.Subscribers.create(\"user@example.com\")\n    {:ok, %{\n      \"email\" => \"user@example.com\"\n    }}","ref":"BentoSdk.Subscribers.html#create/1-examples"},{"type":"function","title":"BentoSdk.Subscribers.find/1","doc":"Find a subscriber by email.","ref":"BentoSdk.Subscribers.html#find/1"},{"type":"function","title":"Examples - BentoSdk.Subscribers.find/1","doc":"BentoSdk.Subscribers.find(\"user@example.com\")\n    {:ok, %{\n      \"email\" => \"user@example.com\",\n      \"first_name\" => \"John\",\n      \"last_name\" => \"Doe\"\n    }}\n\n    BentoSdk.Subscribers.find(\"nonexistent@example.com\")\n    {:ok, nil}","ref":"BentoSdk.Subscribers.html#find/1-examples"},{"type":"function","title":"BentoSdk.Subscribers.find_or_create/1","doc":"Find a subscriber by email, or create one if it doesn't exist.","ref":"BentoSdk.Subscribers.html#find_or_create/1"},{"type":"function","title":"Examples - BentoSdk.Subscribers.find_or_create/1","doc":"BentoSdk.Subscribers.find_or_create(\"user@example.com\")\n    {:ok, %{\n      \"email\" => \"user@example.com\"\n    }}","ref":"BentoSdk.Subscribers.html#find_or_create/1-examples"},{"type":"function","title":"BentoSdk.Subscribers.import/1","doc":"Import Subscribers","ref":"BentoSdk.Subscribers.html#import/1"},{"type":"function","title":"Examples - BentoSdk.Subscribers.import/1","doc":"BentoSdk.Subscribers.import([\n      %{\n        email: \"user@example.com\",\n        first_name: \"Billy\",\n        last_name: \"Bob\"\n      },\n      %{\n        email: \"user2@example.com\",\n        first_name: \"Sarah\",\n        last_name: \"Smith\"\n      }\n    ])\n    {:ok, %{\n      \"failed\" => 0,\n      \"results\" => 2\n    }}","ref":"BentoSdk.Subscribers.html#import/1-examples"},{"type":"function","title":"BentoSdk.Subscribers.remove_field/2","doc":"Remove a field from a subscriber.","ref":"BentoSdk.Subscribers.html#remove_field/2"},{"type":"function","title":"Examples - BentoSdk.Subscribers.remove_field/2","doc":"BentoSdk.Subscribers.remove_field(\"user@example.com\", \"company\")\n    {:ok, %{\n      \"success\" => true\n    }}","ref":"BentoSdk.Subscribers.html#remove_field/2-examples"},{"type":"function","title":"BentoSdk.Subscribers.remove_tag/2","doc":"Remove a tag from a subscriber.","ref":"BentoSdk.Subscribers.html#remove_tag/2"},{"type":"function","title":"Examples - BentoSdk.Subscribers.remove_tag/2","doc":"BentoSdk.Subscribers.remove_tag(\"user@example.com\", \"vip\")\n    {:ok, %{\n      \"success\" => true\n    }}","ref":"BentoSdk.Subscribers.html#remove_tag/2-examples"},{"type":"function","title":"BentoSdk.Subscribers.subscribe/1","doc":"Subscribe a user.","ref":"BentoSdk.Subscribers.html#subscribe/1"},{"type":"function","title":"Examples - BentoSdk.Subscribers.subscribe/1","doc":"BentoSdk.Subscribers.subscribe(\"user@example.com\")\n    {:ok, %{\n      \"success\" => true\n    }}","ref":"BentoSdk.Subscribers.html#subscribe/1-examples"},{"type":"function","title":"BentoSdk.Subscribers.unsubscribe/1","doc":"Unsubscribe a user.","ref":"BentoSdk.Subscribers.html#unsubscribe/1"},{"type":"function","title":"Examples - BentoSdk.Subscribers.unsubscribe/1","doc":"BentoSdk.Subscribers.unsubscribe(\"user@example.com\")\n    {:ok, %{\n      \"success\" => true\n    }}","ref":"BentoSdk.Subscribers.html#unsubscribe/1-examples"},{"type":"function","title":"BentoSdk.Subscribers.update/2","doc":"Update a subscriber with the given attributes.\n\nThis uses the Import Subscribers endpoint to update a single subscriber.","ref":"BentoSdk.Subscribers.html#update/2"},{"type":"function","title":"Examples - BentoSdk.Subscribers.update/2","doc":"BentoSdk.Subscribers.update(\"user@example.com\", %{first_name: \"John\", last_name: \"Doe\"})\n    {:ok, %{\n      \"imported\" => 1,\n      \"errors\" => []\n    }}","ref":"BentoSdk.Subscribers.html#update/2-examples"},{"type":"module","title":"BentoSdk.Tags","doc":"Functions for managing tags in Bento.\n\nThe Tags API allows you to:\n- Get all tags in your account\n- Create new tags\n\nTags are a simple named data point you can use to tag subscribers.","ref":"BentoSdk.Tags.html"},{"type":"function","title":"BentoSdk.Tags.create/1","doc":"Create a new tag in your account.","ref":"BentoSdk.Tags.html#create/1"},{"type":"function","title":"Examples - BentoSdk.Tags.create/1","doc":"BentoSdk.Tags.create(\"new_tag\")\n    {:ok, %{\n      \"id\" => \"1234\",\n      \"type\" => \"tags\",\n      \"attributes\" => %{\n        \"name\" => \"new_tag\",\n        \"created_at\" => \"2024-08-06T05:44:04.444Z\",\n        \"discarded_at\" => nil\n      }\n    }}","ref":"BentoSdk.Tags.html#create/1-examples"},{"type":"function","title":"BentoSdk.Tags.get/0","doc":"Get all tags in your account.","ref":"BentoSdk.Tags.html#get/0"},{"type":"function","title":"Examples - BentoSdk.Tags.get/0","doc":"BentoSdk.Tags.get()\n    {:ok, [\n      %{\n        \"id\" => \"1234\",\n        \"type\" => \"tags\",\n        \"attributes\" => %{\n          \"name\" => \"example_tag\",\n          \"created_at\" => \"2024-08-06T05:44:04.444Z\",\n          \"discarded_at\" => nil\n        }\n      }\n    ]}","ref":"BentoSdk.Tags.html#get/0-examples"},{"type":"module","title":"BentoSdk.Utility","doc":"Utility functions provided by the Bento API.\n\nThis module provides access to Bento's utility APIs for:\n- Content moderation\n- Gender guessing\n- IP geolocation\n- Email validation\n- Blacklist checking","ref":"BentoSdk.Utility.html"},{"type":"function","title":"BentoSdk.Utility.check_blacklist/1","doc":"Check if a domain or IP address is on any blacklists.","ref":"BentoSdk.Utility.html#check_blacklist/1"},{"type":"function","title":"Parameters - BentoSdk.Utility.check_blacklist/1","doc":"- `params` - A map containing either:\n  - `:domain` - The domain to check (e.g., \"example.com\")\n  - `:ip_address` - The IP address to check","ref":"BentoSdk.Utility.html#check_blacklist/1-parameters"},{"type":"function","title":"Examples - BentoSdk.Utility.check_blacklist/1","doc":"BentoSdk.Utility.check_blacklist(%{domain: \"example.com\"})\n    {:ok, %{\n      \"query\" => \"example.com\",\n      \"description\" => \"If any of the following blacklist providers contains true you have a problem on your hand.\",\n      \"results\" => %{\n        \"just_registered\" => false,\n        \"spamhaus\" => false,\n        \"nordspam\" => false,\n        \"spfbl\" => false,\n        \"sorbs\" => false,\n        \"abusix\" => false\n      }\n    }}","ref":"BentoSdk.Utility.html#check_blacklist/1-examples"},{"type":"function","title":"BentoSdk.Utility.geolocate/1","doc":"Geolocate an IP address.","ref":"BentoSdk.Utility.html#geolocate/1"},{"type":"function","title":"Examples - BentoSdk.Utility.geolocate/1","doc":"BentoSdk.Utility.geolocate(\"8.8.8.8\")\n    {:ok, %{\n      \"country_name\" => \"United States\",\n      \"country_code2\" => \"US\",\n      \"city_name\" => \"Mountain View\",\n      \"latitude\" => 37.4056,\n      \"longitude\" => -122.0775\n    }}","ref":"BentoSdk.Utility.html#geolocate/1-examples"},{"type":"function","title":"BentoSdk.Utility.guess_gender/1","doc":"Guess the gender of a name.","ref":"BentoSdk.Utility.html#guess_gender/1"},{"type":"function","title":"Examples - BentoSdk.Utility.guess_gender/1","doc":"BentoSdk.Utility.guess_gender(\"John\")\n    {:ok, %{\n      \"gender\" => \"male\",\n      \"confidence\" => 0.95\n    }}","ref":"BentoSdk.Utility.html#guess_gender/1-examples"},{"type":"function","title":"BentoSdk.Utility.jesses_ruleset/2","doc":"Check an email against Jesse's ruleset.\n\nJesse's ruleset is a custom ruleset created by the founder of Bento that\nis extremely strict. It's recommended to log failures to monitor for false positives.","ref":"BentoSdk.Utility.html#jesses_ruleset/2"},{"type":"function","title":"Parameters - BentoSdk.Utility.jesses_ruleset/2","doc":"- `email` - The email address to validate\n- `opts` - Optional parameters:\n  - `:block_free_providers` - Whether to block free email providers\n  - `:wiggleroom` - Set to true to reduce a few extremely opinionated checks","ref":"BentoSdk.Utility.html#jesses_ruleset/2-parameters"},{"type":"function","title":"Examples - BentoSdk.Utility.jesses_ruleset/2","doc":"BentoSdk.Utility.jesses_ruleset(\"test@example.com\")\n    {:ok, []}\n\n    BentoSdk.Utility.jesses_ruleset(\"test@example.com\", block_free_providers: true)\n    {:ok, [\"Email provider is free\"]}","ref":"BentoSdk.Utility.html#jesses_ruleset/2-examples"},{"type":"function","title":"BentoSdk.Utility.moderate_content/1","doc":"Moderate content for profanity and inappropriate content.","ref":"BentoSdk.Utility.html#moderate_content/1"},{"type":"function","title":"Examples - BentoSdk.Utility.moderate_content/1","doc":"BentoSdk.Utility.moderate_content(\"This is some content to check\")\n    {:ok, %{\n      \"valid\" => true,\n      \"reasons\" => [],\n      \"safe_original_content\" => \"This is some content to check\"\n    }}","ref":"BentoSdk.Utility.html#moderate_content/1-examples"},{"type":"function","title":"BentoSdk.Utility.validate_email/2","doc":"Validate an email address using Bento's validation service.","ref":"BentoSdk.Utility.html#validate_email/2"},{"type":"function","title":"Parameters - BentoSdk.Utility.validate_email/2","doc":"- `email` - The email address to validate\n- `opts` - Optional parameters:\n  - `:name` - The contact's full name\n  - `:user_agent` - The user agent string\n  - `:ip` - The user's IP address","ref":"BentoSdk.Utility.html#validate_email/2-parameters"},{"type":"function","title":"Examples - BentoSdk.Utility.validate_email/2","doc":"BentoSdk.Utility.validate_email(\"test@example.com\")\n    {:ok, %{\"valid\" => true}}\n\n    BentoSdk.Utility.validate_email(\"test@example.com\", name: \"John Doe\", ip: \"8.8.8.8\")\n    {:ok, %{\"valid\" => true}}","ref":"BentoSdk.Utility.html#validate_email/2-examples"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.2"}}